@@ -32,18 +32,20 @@
 #' }
 #' @export
 #' @keywords internal
-legacy_github <- function(repo,
-                          branch = NULL,
-                          token = NULL,
-                          path = "",
-                          host = "https://api.github.com",
-                          name = "github",
-                          cache = NULL,
-                          ...) {
-
+legacy_github <- function(
+  repo,
+  branch = NULL,
+  token = NULL,
+  path = "",
+  host = "https://api.github.com",
+  name = "github",
+  cache = NULL,
+  ...
+) {
   cache <- cache %||% board_cache_path(name)
 
-  board <- new_board_v0("pins_board_github",
+  board <- new_board_v0(
+    "pins_board_github",
     name = name,
     token = token,
     repo = repo,
@@ -54,14 +56,32 @@ legacy_github <- function(repo,
   )
 
   # check repo exists
-  check_exists <- httr::GET(github_url(board, branch = NULL), github_headers(board))
+  check_exists <- httr::GET(
+    github_url(board, branch = NULL),
+    github_headers(board)
+  )
   if (httr::http_error(check_exists)) {
-    stop("The repo '", board$repo, "' does not exist or can't be accessed: ", httr::content(check_exists, encoding = "UTF-8")$message)
+    stop(
+      "The repo '",
+      board$repo,
+      "' does not exist or can't be accessed: ",
+      httr::content(check_exists, encoding = "UTF-8")$message
+    )
   }
 
   branches <- tryCatch(github_branches(board), error = function(e) e)
-  if ("error" %in% class(branches) && grepl("^Git Repository is empty", branches$message)) {
-    github_update_index(board, "", "initialize repo", operation = "initialize", branch = "main")
+  if (
+    "error" %in%
+      class(branches) &&
+      grepl("^Git Repository is empty", branches$message)
+  ) {
+    github_update_index(
+      board,
+      "",
+      "initialize repo",
+      operation = "initialize",
+      branch = "main"
+    )
     branches <- github_branches(board)
   }
 
@@ -71,7 +91,9 @@ legacy_github <- function(repo,
     } else if ("master" %in% branches) {
       branch <- "master"
     } else {
-      abort("No 'master' or 'main' branch present; please use `branch` argument")
+      abort(
+        "No 'master' or 'main' branch present; please use `branch` argument"
+      )
     }
   } else if (is_string(branch)) {
     if (!branch %in% branches) {
@@ -91,15 +113,17 @@ legacy_github <- function(repo,
 
 #' @rdname legacy_github
 #' @export
-board_register_github <- function(name = "github",
-                                  repo = NULL,
-                                  branch = NULL,
-                                  token = NULL,
-                                  path = "",
-                                  host = "https://api.github.com",
-                                  cache = NULL,
-                                  ...) {
-  lifecycle::deprecate_soft(
+board_register_github <- function(
+  name = "github",
+  repo = NULL,
+  branch = NULL,
+  token = NULL,
+  path = "",
+  host = "https://api.github.com",
+  cache = NULL,
+  ...
+) {
+  lifecycle::deprecate_warn(
     "1.4.0",
     "board_register_github()",
     details = 'Learn more at <https://pins.rstudio.com/articles/pins-update.html>'
@@ -131,8 +155,22 @@ github_headers <- function(board) {
   httr::add_headers(Authorization = paste("token", github_auth(board)))
 }
 
-github_update_temp_index <- function(board, path, commit, operation, name = NULL, metadata = NULL, branch = board$branch) {
-  index_url <- github_url(board, branch = branch, "/contents/", board$path, "data.txt")
+github_update_temp_index <- function(
+  board,
+  path,
+  commit,
+  operation,
+  name = NULL,
+  metadata = NULL,
+  branch = board$branch
+) {
+  index_url <- github_url(
+    board,
+    branch = branch,
+    "/contents/",
+    board$path,
+    "data.txt"
+  )
   response <- httr::GET(index_url, github_headers(board))
 
   sha <- NULL
@@ -143,18 +181,23 @@ github_update_temp_index <- function(board, path, commit, operation, name = NULL
 
     # API returns contents when size < 1mb
     if (!is.null(content$content)) {
-      index <- board_manifest_load(rawToChar(jsonlite::base64_dec(content$content)))
-    }
-    else {
+      index <- board_manifest_load(rawToChar(jsonlite::base64_dec(
+        content$content
+      )))
+    } else {
       response <- httr::GET(content$download_url, github_headers(board))
       if (!httr::http_error(response)) {
-        index <- board_manifest_load(httr::content(response, encoding = "UTF-8"))
+        index <- board_manifest_load(httr::content(
+          response,
+          encoding = "UTF-8"
+        ))
       }
     }
   }
 
   index_matches <- sapply(index, function(e) identical(e$path, path))
-  index_pos <- if (length(index_matches) > 0) which(index_matches) else length(index) + 1
+  index_pos <- if (length(index_matches) > 0) which(index_matches) else
+    length(index) + 1
   if (length(index_pos) == 0) index_pos <- length(index) + 1
 
   if (identical(operation, "create")) {
@@ -165,14 +208,11 @@ github_update_temp_index <- function(board, path, commit, operation, name = NULL
       if (!is.null(name)) list(name = name) else NULL,
       metadata
     )
-  }
-  else if (identical(operation, "remove")) {
+  } else if (identical(operation, "remove")) {
     if (index_pos <= length(index)) index[[index_pos]] <- NULL
-  }
-  else if (identical(operation, "initialize")) {
+  } else if (identical(operation, "initialize")) {
     index <- list()
-  }
-  else {
+  } else {
     stop("Operation ", operation, " is unsupported")
   }
 
@@ -185,39 +225,75 @@ github_update_temp_index <- function(board, path, commit, operation, name = NULL
   )
 }
 
-github_update_index <- function(board, path, commit, operation, name = NULL, metadata = NULL, branch = board$branch) {
-  index <- github_update_temp_index(board, path, commit, operation, name = NULL, metadata = NULL, branch = board$branch)
+github_update_index <- function(
+  board,
+  path,
+  commit,
+  operation,
+  name = NULL,
+  metadata = NULL,
+  branch = board$branch
+) {
+  index <- github_update_temp_index(
+    board,
+    path,
+    commit,
+    operation,
+    name = NULL,
+    metadata = NULL,
+    branch = board$branch
+  )
   index_file <- index$index_file
   sha <- index$sha
 
-  file_url <- github_url(board, branch = branch, "/contents/", board$path, "data.txt")
+  file_url <- github_url(
+    board,
+    branch = branch,
+    "/contents/",
+    board$path,
+    "data.txt"
+  )
 
   base64 <- base64enc_file(index_file)
-  response <- httr::PUT(file_url,
+  response <- httr::PUT(
+    file_url,
     body = list(
       message = commit,
       content = base64,
       sha = sha,
       branch = branch
     ),
-    github_headers(board), encode = "json"
+    github_headers(board),
+    encode = "json"
   )
 
   if (httr::http_error(response)) {
-    stop("Failed to update data.txt file: ", httr::content(response, encoding = "UTF-8"))
+    stop(
+      "Failed to update data.txt file: ",
+      httr::content(response, encoding = "UTF-8")
+    )
   }
 }
 
 github_delete_release <- function(board, release_tag) {
-  response <- httr::GET(github_url(board, branch = NULL, paste0("/releases/tags/", release_tag)), github_headers(board))
+  response <- httr::GET(
+    github_url(board, branch = NULL, paste0("/releases/tags/", release_tag)),
+    github_headers(board)
+  )
   if (!httr::http_error(response)) {
     release_id <- httr::content(response, encoding = "UTF-8")$id
-    response <- httr::DELETE(github_url(board, branch = NULL, paste0("/releases/", release_id)), github_headers(board))
+    response <- httr::DELETE(
+      github_url(board, branch = NULL, paste0("/releases/", release_id)),
+      github_headers(board)
+    )
     if (httr::http_error(response)) {
       pin_log("Failed to delete release ", release_id)
     }
 
-    response <- httr::DELETE(github_url(board, branch = NULL, paste0("/git/refs/tags/", release_tag)), github_headers(board))
+    response <- httr::DELETE(
+      github_url(board, branch = NULL, paste0("/git/refs/tags/", release_tag)),
+      github_headers(board)
+    )
     if (httr::http_error(response)) {
       pin_log("Failed to delete tag ", release_tag)
     }
@@ -228,7 +304,8 @@ github_create_release <- function(board, name) {
   index_url <- github_url(board, branch = NULL, "/commits/", board$branch)
   response <- httr::GET(index_url, github_headers(board))
   version <- "initial"
-  if (!httr::http_error(response)) version <- substr(httr::content(response, encoding = "UTF-8")$sha, 1, 7)
+  if (!httr::http_error(response))
+    version <- substr(httr::content(response, encoding = "UTF-8")$sha, 1, 7)
 
   release_url <- github_url(board, branch = NULL, "/releases")
 
@@ -236,8 +313,7 @@ github_create_release <- function(board, name) {
   if (board_versions_enabled(board, TRUE)) {
     release_tag <- paste(name, version, sep = "-")
     release_name <- paste(name, version)
-  }
-  else {
+  } else {
     # attempt to delete existing release
     github_delete_release(board, release_tag)
   }
@@ -246,16 +322,29 @@ github_create_release <- function(board, name) {
     tag_name = release_tag,
     target_commitish = board$branch,
     name = release_name,
-    body = paste0("Storage for resource '", name, "' which is too large to be stored as a GitHub file.")
+    body = paste0(
+      "Storage for resource '",
+      name,
+      "' which is too large to be stored as a GitHub file."
+    )
   )
 
   response <- httr::POST(
     release_url,
     body = release,
-    github_headers(board), encode = "json"
+    github_headers(board),
+    encode = "json"
   )
 
-  if (httr::http_error(response)) stop("Failed to create release '", release$tag_name, "' for '", name, "': ", httr::content(response, encoding = "UTF-8")$message)
+  if (httr::http_error(response))
+    stop(
+      "Failed to create release '",
+      release$tag_name,
+      "' for '",
+      name,
+      "': ",
+      httr::content(response, encoding = "UTF-8")$message
+    )
 
   httr::content(response, encoding = "UTF-8")
 }
@@ -271,24 +360,48 @@ github_upload_release <- function(board, release, name, file, file_path) {
     http_utils_progress("up", size = file.info(normalizePath(file_path))$size)
   )
 
-  if (httr::http_error(response)) stop("Failed to upload asset '", file, "': ", httr::content(response, encoding = "UTF-8")$message)
+  if (httr::http_error(response))
+    stop(
+      "Failed to upload asset '",
+      file,
+      "': ",
+      httr::content(response, encoding = "UTF-8")$message
+    )
 
   httr::content(response, encoding = "UTF-8")$url
 }
 
-github_upload_content <- function(board, name, file, file_path, commit, sha, branch) {
-  file_url <- github_url(board, branch = branch, "/contents/", board$path, name, "/", file)
+github_upload_content <- function(
+  board,
+  name,
+  file,
+  file_path,
+  commit,
+  sha,
+  branch
+) {
+  file_url <- github_url(
+    board,
+    branch = branch,
+    "/contents/",
+    board$path,
+    name,
+    "/",
+    file
+  )
   pin_log("uploading ", file_url)
 
   base64 <- base64enc_file(file_path)
-  response <- httr::PUT(file_url,
+  response <- httr::PUT(
+    file_url,
     body = list(
       message = commit,
       content = base64,
       sha = sha,
       branch = branch
     ),
-    github_headers(board), encode = "json",
+    github_headers(board),
+    encode = "json",
     http_utils_progress("up", size = file.info(normalizePath(file_path))$size)
   )
   upload <- httr::content(response, encoding = "UTF-8")
@@ -304,12 +417,14 @@ github_upload_blob <- function(board, file, file_path, commit) {
   pin_log("uploading ", file)
 
   base64 <- base64enc_file(file_path)
-  response <- httr::POST(blob_url,
+  response <- httr::POST(
+    blob_url,
     body = list(
       content = base64,
       encoding = "base64"
     ),
-    github_headers(board), encode = "json",
+    github_headers(board),
+    encode = "json",
     http_utils_progress("up", size = file.info(normalizePath(file_path))$size)
   )
   upload <- httr::content(response, encoding = "UTF-8")
@@ -326,12 +441,14 @@ github_create_tree <- function(board, tree_files, base_sha) {
   tree_url <- github_url(board, branch = NULL, "/git/trees")
   pin_log("creating tree")
 
-  response <- httr::POST(tree_url,
+  response <- httr::POST(
+    tree_url,
     body = list(
       base_tree = jsonlite::unbox(base_sha),
       tree = tree_files
     ),
-    github_headers(board), encode = "json",
+    github_headers(board),
+    encode = "json",
     http_utils_progress("up")
   )
   upload <- httr::content(response, encoding = "UTF-8")
@@ -348,7 +465,8 @@ github_create_commit <- function(board, tree_sha, base_sha, commit) {
   commit_url <- github_url(board, branch = NULL, "/git/commits")
   pin_log("creating commit")
 
-  response <- httr::POST(commit_url,
+  response <- httr::POST(
+    commit_url,
     body = list(
       message = jsonlite::unbox(commit),
       tree = jsonlite::unbox(tree_sha),
@@ -356,7 +474,8 @@ github_create_commit <- function(board, tree_sha, base_sha, commit) {
         jsonlite::unbox(base_sha)
       )
     ),
-    github_headers(board), encode = "json",
+    github_headers(board),
+    encode = "json",
     http_utils_progress("up")
   )
   upload <- httr::content(response, encoding = "UTF-8")
@@ -370,16 +489,22 @@ github_create_commit <- function(board, tree_sha, base_sha, commit) {
 }
 
 github_update_head <- function(board, branch, commit_sha) {
-  ref_url <- github_url(board, branch = NULL, paste0("/git/refs/heads/", branch))
+  ref_url <- github_url(
+    board,
+    branch = NULL,
+    paste0("/git/refs/heads/", branch)
+  )
   pin_log("updating head")
 
-  response <- httr::VERB("PATCH",
+  response <- httr::VERB(
+    "PATCH",
     ref_url,
     body = list(
       sha = jsonlite::unbox(commit_sha),
       force = jsonlite::unbox(FALSE)
     ),
-    github_headers(board), encode = "json",
+    github_headers(board),
+    encode = "json",
     http_utils_progress("up")
   )
   upload <- httr::content(response, encoding = "UTF-8")
@@ -420,14 +545,29 @@ github_files_commit <- function(board, upload_files, branch, commit) {
   }
 
   head_sha <- github_refs_head(board, branch)
-  tree_result <- github_create_tree(board, unname(tree_files), head_sha$object$sha)
-  commit_result <- github_create_commit(board, tree_result$sha, head_sha$object$sha, commit)
+  tree_result <- github_create_tree(
+    board,
+    unname(tree_files),
+    head_sha$object$sha
+  )
+  commit_result <- github_create_commit(
+    board,
+    tree_result$sha,
+    head_sha$object$sha,
+    commit
+  )
 
   github_update_head(board, branch, commit_result$sha)
 }
 
 #' @export
-board_pin_create.pins_board_github <- function(board, path, name, metadata, ...) {
+board_pin_create.pins_board_github <- function(
+  board,
+  path,
+  name,
+  metadata,
+  ...
+) {
   update_index <- !identical(list(...)$index, FALSE)
   description <- list(...)$description
   branch <- if (is.null(list(...)$branch)) board$branch else list(...)$branch
@@ -447,8 +587,7 @@ board_pin_create.pins_board_github <- function(board, path, name, metadata, ...)
 
   if (dir.exists(path)) {
     file.copy(file.path(path, dir(path)), bundle_path, recursive = TRUE)
-  }
-  else {
+  } else {
     file.copy(path, bundle_path)
   }
 
@@ -460,9 +599,20 @@ board_pin_create.pins_board_github <- function(board, path, name, metadata, ...)
   for (file in upload_files) {
     file_path <- file.path(bundle_path, file)
 
-    if ((file.info(file_path)$size > getOption("pins.github.release", 25) * 10^6 || release_storage) && !identical(file, "data.txt")) {
+    if (
+      (file.info(file_path)$size >
+        getOption("pins.github.release", 25) * 10^6 ||
+        release_storage) &&
+        !identical(file, "data.txt")
+    ) {
       if (is.null(release)) release <- github_create_release(board, name)
-      download_url <- github_upload_release(board, release, name, file, file_path)
+      download_url <- github_upload_release(
+        board,
+        release,
+        name,
+        file,
+        file_path
+      )
       release_map[[file]] <- download_url
     }
   }
@@ -495,9 +645,14 @@ board_pin_create.pins_board_github <- function(board, path, name, metadata, ...)
   if (update_index) {
     index_path <- name
 
-    index <- github_update_temp_index(board, index_path, commit,
+    index <- github_update_temp_index(
+      board,
+      index_path,
+      commit,
       operation = "create",
-      name = name, metadata = metadata, branch = branch
+      name = name,
+      metadata = metadata,
+      branch = branch
     )
 
     remote_index <- paste0(board$path, "data.txt")
@@ -505,7 +660,8 @@ board_pin_create.pins_board_github <- function(board, path, name, metadata, ...)
   }
 
   # add remaining files in a single commit
-  commit <- if (is.null(list(...)$commit)) paste("update", name) else list(...)$commit
+  commit <- if (is.null(list(...)$commit)) paste("update", name) else
+    list(...)$commit
   github_files_commit(board, upload_defs, branch, commit)
 }
 
@@ -523,32 +679,49 @@ board_pin_find.pins_board_github <- function(board, text, ...) {
     if (is.null(content$content)) {
       result <- httr::GET(content$download_url, github_headers(board))
       content <- httr::content(result, encoding = "UTF-8")
-    }
-    else {
+    } else {
       content <- rawToChar(jsonlite::base64_dec(content$content))
     }
 
     result <- board_manifest_load(content) %>%
       pin_results_from_rows()
-  }
-  else {
-    pin_log("Failed to find 'data.txt' file in repo '", board$repo, "', path '", board$path, "' and branch '", branch, "'.")
+  } else {
+    pin_log(
+      "Failed to find 'data.txt' file in repo '",
+      board$repo,
+      "', path '",
+      board$path,
+      "' and branch '",
+      branch,
+      "'."
+    )
     result <- pin_find_empty()
   }
 
   if (is.character(text)) {
-    result <- result[grepl(text, result$name) | grepl(text, result$description), ]
+    result <- result[
+      grepl(text, result$name) | grepl(text, result$description),
+    ]
   }
 
   if (nrow(result) == 1) {
     # retrieve additional details if searching for only one item
     result_single <- httr::GET(
-      github_url(board, branch = branch, "/contents/", board$path, result$name, "/", "data.txt"),
+      github_url(
+        board,
+        branch = branch,
+        "/contents/",
+        board$path,
+        result$name,
+        "/",
+        "data.txt"
+      ),
       github_headers(board)
     )
 
     if (!httr::http_error(result_single)) {
-      local_path <- pin_download_files(httr::content(result_single, encoding = "UTF-8")$download_url,
+      local_path <- pin_download_files(
+        httr::content(result_single, encoding = "UTF-8")$download_url,
         result$name,
         board,
         headers = github_headers(board),
@@ -556,7 +729,10 @@ board_pin_find.pins_board_github <- function(board, text, ...) {
       )
       manifest <- pin_manifest_get(local_path)
 
-      result$metadata <- as.character(jsonlite::toJSON(manifest, auto_unbox = TRUE))
+      result$metadata <- as.character(jsonlite::toJSON(
+        manifest,
+        auto_unbox = TRUE
+      ))
     }
   }
 
@@ -575,8 +751,12 @@ github_url <- function(board, branch = board$branch, ...) {
 }
 
 github_branches <- function(board) {
-  response <- httr::GET(github_url(board, "/git", "/refs", branch = NULL), github_headers(board))
-  if (httr::http_error(response)) stop(httr::content(response, encoding = "UTF-8"))
+  response <- httr::GET(
+    github_url(board, "/git", "/refs", branch = NULL),
+    github_headers(board)
+  )
+  if (httr::http_error(response))
+    stop(httr::content(response, encoding = "UTF-8"))
 
   httr::content(response, encoding = "UTF-8") %>%
     sapply(function(e) gsub("refs/heads/", "", e$ref))
@@ -585,13 +765,22 @@ github_branches <- function(board) {
 github_branch <- function(board, branch) {
   reference <- paste0("refs/heads/", branch)
 
-  response <- httr::GET(github_url(board, "/git", "/refs", branch = NULL), github_headers(board))
+  response <- httr::GET(
+    github_url(board, "/git", "/refs", branch = NULL),
+    github_headers(board)
+  )
 
   if (httr::http_error(response)) {
-    stop("Failed to retrieve branches ", as.character(httr::content(response, encoding = "UTF-8")))
+    stop(
+      "Failed to retrieve branches ",
+      as.character(httr::content(response, encoding = "UTF-8"))
+    )
   }
 
-  branch_object <- Filter(function(e) identical(e$ref, reference), httr::content(response, encoding = "UTF-8"))
+  branch_object <- Filter(
+    function(e) identical(e$ref, reference),
+    httr::content(response, encoding = "UTF-8")
+  )
 
   if (length(branch_object) != 1) stop("Failed to retrieve branch ", branch)
 
@@ -608,18 +797,30 @@ github_branches_create <- function(board, new_branch, base_branch) {
       ref = reference,
       sha = sha
     ),
-    github_headers(board), encode = "json"
+    github_headers(board),
+    encode = "json"
   )
 
   if (httr::http_error(response)) {
-    stop("Failed to create branch ", new_branch, " ", as.character(httr::content(response, encoding = "UTF-8")))
+    stop(
+      "Failed to create branch ",
+      new_branch,
+      " ",
+      as.character(httr::content(response, encoding = "UTF-8"))
+    )
   }
 }
 
 github_content_url <- function(board, branch = board$branch, ...) {
   args <- list(...)
 
-  url <- paste0(board$host, "/repos/", board$repo, "/contents/", paste0(board$path, paste0(args, collapse = "")))
+  url <- paste0(
+    board$host,
+    "/repos/",
+    board$repo,
+    "/contents/",
+    paste0(board$path, paste0(args, collapse = ""))
+  )
   if (!is.null(branch)) {
     url <- paste0(url, "?ref=", branch)
   }
@@ -628,7 +829,14 @@ github_content_url <- function(board, branch = board$branch, ...) {
 }
 
 github_raw_url <- function(board, branch = board$branch, ...) {
-  paste0("https://raw.githubusercontent.com/", board$repo, "/", branch, "/", paste0(..., collapse = ""))
+  paste0(
+    "https://raw.githubusercontent.com/",
+    board$repo,
+    "/",
+    branch,
+    "/",
+    paste0(..., collapse = "")
+  )
 }
 
 github_download_files <- function(index, temp_path, board) {
@@ -636,21 +844,33 @@ github_download_files <- function(index, temp_path, board) {
     pin_log("retrieving ", file$download_url)
 
     if (is.list(file) && identical(file$type, "dir")) {
-      sub_index <- httr::GET(file$url, github_headers(board), http_utils_progress()) %>% httr::content(encoding = "UTF-8")
+      sub_index <- httr::GET(
+        file$url,
+        github_headers(board),
+        http_utils_progress()
+      ) %>%
+        httr::content(encoding = "UTF-8")
       github_download_files(sub_index, file.path(temp_path, file$name), board)
-    }
-    else {
+    } else {
       if (!dir.exists(temp_path)) dir.create(temp_path, recursive = TRUE)
       httr::GET(
-        file$download_url, httr::write_disk(file.path(temp_path, basename(file$download_url))),
-        http_utils_progress(), github_headers(board)
+        file$download_url,
+        httr::write_disk(file.path(temp_path, basename(file$download_url))),
+        http_utils_progress(),
+        github_headers(board)
       )
     }
   }
 }
 
 #' @export
-board_pin_get.pins_board_github <- function(board, name, extract = NULL, version = NULL, ...) {
+board_pin_get.pins_board_github <- function(
+  board,
+  name,
+  extract = NULL,
+  version = NULL,
+  ...
+) {
   branch <- if (is.null(list(...)$branch)) board$branch else list(...)$branch
   subpath <- name
 
@@ -659,8 +879,20 @@ board_pin_get.pins_board_github <- function(board, name, extract = NULL, version
     subpath <- file.path(name, pin_versions_path_name(), version)
   }
 
-  base_url <- github_raw_url(board, branch = branch, board$path, name, "/data.txt")
-  local_path <- pin_download_files(base_url, name, board, headers = github_headers(board), subpath = subpath)
+  base_url <- github_raw_url(
+    board,
+    branch = branch,
+    board$path,
+    name,
+    "/data.txt"
+  )
+  local_path <- pin_download_files(
+    base_url,
+    name,
+    board,
+    headers = github_headers(board),
+    subpath = subpath
+  )
 
   if (file.exists(file.path(local_path, "data.txt"))) {
     index_path <- pin_manifest_download(local_path, namemap = TRUE)
@@ -669,18 +901,29 @@ board_pin_get.pins_board_github <- function(board, name, extract = NULL, version
       file <- index_path[file_idx]
       file_url <- file
       headers <- github_headers(board)
-      file_name <- if (!identical(names(index_path), NULL) && nchar(names(index_path)[file_idx]) > 0) names(index_path)[file_idx] else NULL
+      file_name <- if (
+        !identical(names(index_path), NULL) &&
+          nchar(names(index_path)[file_idx]) > 0
+      )
+        names(index_path)[file_idx] else NULL
 
       if (grepl("^http://|^https://", file)) {
         # manually move authorization to url due to https://github.com/octokit/rest.js/issues/967
         file_url <- paste0(file_url, "?access_token=", github_auth(board))
         headers <- httr::add_headers(Accept = "application/octet-stream")
-      }
-      else {
-        file_url <- github_raw_url(board, branch = branch, board$path, name, "/", file)
+      } else {
+        file_url <- github_raw_url(
+          board,
+          branch = branch,
+          board$path,
+          name,
+          "/",
+          file
+        )
       }
 
-      pin_download_files(file_url,
+      pin_download_files(
+        file_url,
         name,
         board,
         headers = headers,
@@ -691,15 +934,21 @@ board_pin_get.pins_board_github <- function(board, name, extract = NULL, version
     }
 
     local_path
-  }
-  else {
+  } else {
     base_url <- github_raw_url(board, branch = branch, board$path, name)
     result <- httr::GET(base_url, github_headers(board))
 
     index <- httr::content(result, encoding = "UTF-8")
 
     if (httr::http_error(result)) {
-      stop("Failed to retrieve ", name, " from ", board$repo, ": ", index$message)
+      stop(
+        "Failed to retrieve ",
+        name,
+        " from ",
+        board$repo,
+        ": ",
+        index$message
+      )
     }
 
     # need to handle case where users passes a full URL to the specific file to download
@@ -722,7 +971,10 @@ board_pin_remove.pins_board_github <- function(board, name, ...) {
   update_index <- !identical(list(...)$index, FALSE)
 
   base_url <- github_content_url(board, name, branch = NULL)
-  result <- httr::GET(paste0(base_url, "?ref=", board$branch), github_headers(board))
+  result <- httr::GET(
+    paste0(base_url, "?ref=", board$branch),
+    github_headers(board)
+  )
 
   index <- httr::content(result, encoding = "UTF-8")
 
@@ -733,18 +985,31 @@ board_pin_remove.pins_board_github <- function(board, name, ...) {
   for (file in index) {
     pin_log("deleting ", file$name)
 
-    commit <- if (is.null(list(...)$commit)) paste("delete", file$name) else list(...)$commit
+    commit <- if (is.null(list(...)$commit)) paste("delete", file$name) else
+      list(...)$commit
 
-    response <- httr::DELETE(file.path(base_url, file$name), body = list(
-      message = commit,
-      sha = file$sha,
-      branch = board$branch
-    ), github_headers(board), encode = "json")
+    response <- httr::DELETE(
+      file.path(base_url, file$name),
+      body = list(
+        message = commit,
+        sha = file$sha,
+        branch = board$branch
+      ),
+      github_headers(board),
+      encode = "json"
+    )
 
     deletion <- httr::content(response, encoding = "UTF-8")
 
     if (httr::http_error(response)) {
-      stop("Failed to delete ", name, " from ", board$repo, ": ", deletion$message)
+      stop(
+        "Failed to delete ",
+        name,
+        " from ",
+        board$repo,
+        ": ",
+        deletion$message
+      )
     }
   }
 
@@ -752,12 +1017,25 @@ board_pin_remove.pins_board_github <- function(board, name, ...) {
     github_delete_release(board, name)
   }
 
-  if (update_index) github_update_index(board, paste0(board$path, name), commit, operation = "remove")
+  if (update_index)
+    github_update_index(
+      board,
+      paste0(board$path, name),
+      commit,
+      operation = "remove"
+    )
 }
 
 #' @export
 board_browse.pins_board_github <- function(board, ...) {
-  utils::browseURL(paste0("https://github.com/", board$repo, "/tree/", board$branch, "/", board$path))
+  utils::browseURL(paste0(
+    "https://github.com/",
+    board$repo,
+    "/tree/",
+    board$branch,
+    "/",
+    board$path
+  ))
 }
 
 #' @export
@@ -766,10 +1044,14 @@ board_pin_versions.pins_board_github <- function(board, name, ...) {
 
   path <- paste0(board$path, name)
   response <- httr::GET(
-    github_url(board, "/commits",
+    github_url(
+      board,
+      "/commits",
       branch = NULL,
-      sha = "?per_page=100&sha=", branch,
-      "&path=", path
+      sha = "?per_page=100&sha=",
+      branch,
+      "&path=",
+      path
     ),
     github_headers(board)
   )
