@@ -119,3 +119,16 @@ null_if_na <- function(x) {
 is_rcmd_check <- function() {
   Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
 }
+
+# adapted from ps:::is_cran_check()
+# nocov start
+
+is_cran_check <- function () {
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    FALSE
+  } else {
+    Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
+  }
+}
+
+#nocov end
